# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class RequestStatusResponse(UniversalBaseModel):
    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    The error message, if available
    """

    response: typing.Optional[typing.Any] = None
    status: str = pydantic.Field()
    """
    The current status of the request (pending, completed, error)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
