# This file was auto-generated by Fern from our API Definition.

import typing

FileEventMessageStatus = typing.Union[typing.Literal["available", "uploading", "upload_failed", "deleted"], typing.Any]
