# This file was auto-generated by Fern from our API Definition.

import typing

CreateFileV1FileType = typing.Union[
    typing.Literal["browser_download", "screenshot", "video", "customer_upload"], typing.Any
]
